/*
 * Copyright 2020 Kunbus GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <cstdlib>
#include <cstdio>
#include <unistd.h>

#include <piControlIf.hpp>

using namespace std;

/*!
 * Find out where "RevPiLED" is located in the process image
 */
uint16_t getRevPiLEDAddress(piControl *piC) {

    SPIVariable spiVariableOut = {"RevPiLED", 0, 0, 0};

    if (piC->GetVariableInfo(&spiVariableOut) != 0) {
        return -1;
    } else {
        return (spiVariableOut.i16uAddress);
    }
}

int main(int argc, char** argv) {
    piControl piC;

    SPIValue spiValue = {0, 0, 0};
    spiValue.i16uAddress = getRevPiLEDAddress(&piC);
    spiValue.i8uBit = 0;
    spiValue.i8uValue = 1;
    
    while(true) {
        spiValue.i8uValue = spiValue.i8uValue^0x01;
        piC.SetBitValue(&spiValue);
        sleep(1);
    }

    return 0;
}


